#
# spec file for package python-pygit2
#
# Copyright (c) 2019 SUSE LLC
# Copyright (c) 2019 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pygit2
Version:        0.28.2
Release:        bp153.1.27
Summary:        Python bindings for libgit2
License:        GPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/libgit2/pygit2
Source:         https://files.pythonhosted.org/packages/source/p/pygit2/pygit2-%{version}.tar.gz
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pycparser}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  ca-certificates
BuildRequires:  ca-certificates-mozilla
BuildRequires:  fdupes
BuildRequires:  libgit2-devel >= %{version}
BuildRequires:  libopenssl-devel
BuildRequires:  python-rpm-macros
Requires:       python-pycparser
Requires:       python-six
%requires_eq    python-cffi
%python_subpackages

%description
Bindings for libgit2, a linkable C library for the Git version-control system.

%prep
%setup -q -n pygit2-%{version}
# do not add options to pytest
rm pytest.ini

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand rm -rf %{buildroot}%{$python_sitearch}/pygit2/decl/
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
rm -rf pygit2
# test_no_context_lines failing on big endian
# https://github.com/libgit2/pygit2/issues/812
%pytest_arch -k 'not test_no_context_lines'

%files %{python_files}
%license COPYING
%doc README.rst
%{python_sitearch}/*

%changelog
* Mon Dec  2 2019 Julio González Gil <jgonzalez@suse.com>
- Fix building for s390x (bsc#1158198)
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.28.2:
  * Fix crash in reflog iteration #901
  * Support symbolic references in branches.with_commit(..) #910
  * Documentation updates #909
  * Test updates #911
* Wed May 15 2019 Gary Smith <GSmith@suse.com>
- Update to 0.28.1
  * Removed patch pycparser.patch as it is no longer needed
  * Now works with pycparser 2.18 and above
  * Now ``Repository.write_archive(..)`` keeps the file mode
  * New ``Patch.data`` returns the raw contents of the patch as a byte string
  * New ``Patch.text`` returns the contents of the patch as a text string,
* Mon Apr  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix the pycparser issues as per bellow:
  * pycparser.patch
* Sat Mar 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop the pygit2-0.28-Remove-pycparser-constraint.patch and replace
  it with shorter sed
- Switch to pytest testing:
  * Fails now but that is pycparser bug https://github.com/eliben/pycparser/issues/305
- Disable tests temporarily as per above
* Wed Mar 20 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.28.0
  * Update to libgit2 v0.28
  * New ``pygit2.Mailmap``
  * New ``Repository.apply(...)`` wraps ``git_apply(..)``
  * Now ``Repository.merge_analysis(...)`` accepts an optional reference parameter
  * Now ``Repository.add_worktree(...)`` accepts an optional reference parameter
  * Now it's possible to set SSL certificate locations
  * Test and documentation improvements
  * Now ``worktree.path`` returns the path to the worktree directory
  * Remove undocumented ``worktree.git_path``
- Remove unneeded patch to fix issues on i586:
  * pygit2-i586.patch
- Add patch to remove unneeded constraint on pycparser
  * pygit2-0.28-Remove-pycparser-constraint.patch
* Mon May 21 2018 tchvatal@suse.com
- Add patch to fix issues on i586 arch:
  * pygit2-i586.patch
* Thu May 17 2018 tchvatal@suse.com
- Update to 0.27.0:
  * Update to libgit2 v0.27 #783
  * Fix for GCC 4 #786
* Thu Aug 24 2017 toddrme2178@gmail.com
- Update to 0.26.0
  * Update to libgit2 v0.26
  * Drop support for Python 3.2, add support for cffi 1.10
  * New ``Repository.revert_commit(...)``
  * New ``Branch.is_checked_out()``
  * Various fixes
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update to 0.25.0.
  * Make pygit2 throw if tree of a commit is not found
  * fixed cached memory tests
  * Added mwindow_mapped_limit, cached_memory, enable_caching,
    cache_max_size, cache_object_limit options
- Implement singlespec version.
* Wed Jan 11 2017 astieger@suse.com
- update to 0.24.2:
  * Fix when libgit2 error messages have non-ascii chars
  * Documentation improvements
- includes changes from 0.24.1
  * New Repository.listall_reference_objects()
  * Fix ``Repository.write_archive(...)`
  * Reproducible builds
  * Documentation fixes
* Wed Nov  2 2016 kkaempf@suse.com
- Fix Url link (old one was dead).
* Fri Aug 12 2016 tbechtold@suse.com
- require the cffi version it was built against
- Use pypi.io as Source url
* Thu Apr  7 2016 zaitor@opensuse.org
- Update to version 0.24.0:
  + Support Python 3.5.
  + New dependency, python-six
  + New Repository.path_is_ignored(path).
  + Fix error in Repository(path) when path is a bytes string.
  + Fix memory issue in Repository.describe(...).
  + Allow testing with `tox.
- Add python-six BuildRequires following upstream changes.
* Tue Sep 29 2015 toddrme2178@gmail.com
- Update to version 0.23.1
  * Improve support for cffi 1.0+
    (https://github.com/libgit2/pygit2/pull/529)
    (https://github.com/libgit2/pygit2/pull/561)
  * Fix Remote.push
    (https://github.com/libgit2/pygit2/pull/557)
  * New TreeEntry.type
    (https://github.com/libgit2/pygit2/pull/560)
  * New pygit2.GIT_DIFF_SHOW_BINARY
    (https://github.com/libgit2/pygit2/pull/566)
* Thu Sep 17 2015 p.drouand@gmail.com
- Update to version 0.23.0
  * Update to libgit2 v0.23
    (https://github.com/libgit2/pygit2/pull/540)
  * Now Repository.merge_base(...) returns None if no merge base is found
    (https://github.com/libgit2/pygit2/pull/550)
  * Documentation updates
    (https://github.com/libgit2/pygit2/pull/547)
* Tue Feb  3 2015 dimstar@opensuse.org
- Update to version 0.22.0:
  + Update to libgit2 v0.22
    (https://github.com/libgit2/pygit2/pull/459)
  + Add support for libgit2 feature detection (new pygit2.features
    and pygit2.GIT_FEATURE_*)
    (https://github.com/libgit2/pygit2/pull/475)
  + New Repository.remotes (RemoteCollection)
    (https://github.com/libgit2/pygit2/pull/447)
  + API Changes:
  - Prototype of clone_repository changed, check documentation
  - Removed clone_into, use clone_repository with callbacks instead
  - Use Repository.remotes.rename(name, new_name) instead of
    Remote.rename(new_name)
  - Use Repository.remotes.delete(name) instead of Remote.delete()
  - Now Remote.push(...) takes a list of refspecs instead of just one
  - Change Patch.old_id, Patch.new_id, Note.annotated_id,
    RefLogEntry.oid_old and RefLogEntry.oid_new to be Oid objects
    instead of strings
    (https://github.com/libgit2/pygit2/pull/449)
  + Other:
  - Fix init_repository when passing optional parameters
    workdir_path, description, template_path, initial_head or
    origin_url.
  - Fix use-after-free when patch outlives diff.
  - Documentation improvements.
  - Make the GPL exception explicit in setup.py.
- Add python-setuptools BuildRequires: new build dependency.
* Tue Sep  2 2014 p.drouand@gmail.com
- Update to version 0.20.2
  + Fix regression with Python 2, ``IndexEntry.path`` returns str
    (bytes in Python 2 and unicode in Python 3)
  + Get back ``IndexEntry.oid`` for backwards compatibility
  + Config, iterate over the keys (instead of the key/value pairs)
    `#395 <https://github.com/libgit2/pygit2/pull/395>`_
  + ``Diff.find_similar`` supports new threshold arguments
    `#396 <https://github.com/libgit2/pygit2/pull/396>`_
  + Optimization, do not load the object when expanding an oid prefix
  `#397 <https://github.com/libgit2/pygit2/pull/397>`_
- Changes from version 0.20.1
  + Install fix
    `#382 <https://github.com/libgit2/pygit2/pull/382>`_
  + Documentation improved, including
    `#383 <https://github.com/libgit2/pygit2/pull/383>`_
    `#385 <https://github.com/libgit2/pygit2/pull/385>`_
    `#388 <https://github.com/libgit2/pygit2/pull/388>`_
  + Documentation, use the read-the-docs theme
    `#387 <https://github.com/libgit2/pygit2/pull/387>`_
  + Coding style improvements
    `#392 <https://github.com/libgit2/pygit2/pull/392>`_
  + New ``Repository.state_cleanup()``
    `#386 <https://github.com/libgit2/pygit2/pull/386>`_
  + New ``Index.conflicts``
    `#345 <https://github.com/libgit2/pygit2/issues/345>`_
    `#389 <https://github.com/libgit2/pygit2/pull/389>`_
  + New checkout option to define the target directory
    `#390 <https://github.com/libgit2/pygit2/pull/390>`_
- Fix build
- Remove python_sitelib definition; pygit2 is arch dependant
- Add python-cffi and python-unittest2 requirements; new
  dependencies
- Disable tests; network is now needed for launching them
* Mon Dec  9 2013 p.drouand@gmail.com
- Update to version 0.20.0
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.19.0...v0.20.0
- Fix build on openSUSE >= 12.3 and SLE11SP3
- Remove obsolete conditionnal macros
* Sun Aug 18 2013 toddrme2178@gmail.com
- Update to 0.19.0
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.17.3...v0.19.0
- Keep 0.17.3 for compatibility with openSUSE 12.2
* Thu Dec 27 2012 cfarrell@suse.com
- license update: GPL-2.0
  See COPYING (and the majority of the source code files). Not sure why
  Apache-2.0 was chosen as license here - there is absolutely no indication
  of Apache style licensing in the package
* Tue Dec 18 2012 saschpe@suse.de
- Update to version 0.17.3:
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.17.2...v0.17.3
- Changes from previous versions:
  + https://github.com/libgit2/pygit2/compare/v0.16.1...v0.17.2
- Enable testsuite again
- Package file COPYING
* Tue Apr 24 2012 saschpe@suse.de
- Update to version 0.16.1:
  + Upstream provides no changelog
* Wed Jan 26 2011 saschpe@gmx.de
- Removed SUSE-specific --record-rpm for file lists
* Tue Jan 18 2011 saschpe@gmx.de
- Install documentation (README.md and COPYING)
- Fix install section for other distros
* Tue Jan 18 2011 saschpe@gmx.de
- Initial commit (0.1)
- Added patch include recent libgit2 changes
